import { inject, InjectionKey } from "@vue/composition-api";

export function safeInject<T> (key: InjectionKey<T>): T {
  const store = inject(key);
  if (!store) {
    throw new Error(`Store with key: ${key} not found!`);
  }
  return store;
}

const getLbconfigsEnv = (name: string) => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  return (window as any).lbconfigs?.[name] || process.env[name];
};

export function safeProcessEnv (key: string): string {
  const env = getLbconfigsEnv(key);
  if (!env) {
    throw new Error("missing required env var: " + key);
  }
  return env;
}