
import { LbAuthService, LbAuthServiceKey, useLbAuthService } from "@/core/auth";
import { LbGraphqlService, LbGraphqlServiceKey, useLbGraphqlService } from "@/core/graphql";
import { safeInject } from "@/core/utils";
import { loginRoute } from "@/router";
import { provide } from "@vue/composition-api";
import { safeProcessEnv } from "../core/utils";

export const APP_URL = safeProcessEnv("VUE_APP_URL")

export const authService = useLbAuthService({
  graphqlURL: APP_URL,
  loginUrl: loginRoute.path,
  tokenName: "LbDemoToken",
  exp: 10000,
  rememberExp: 2592000000
});
const gqlClient = useLbGraphqlService({
  gqlApplicationUrl: APP_URL,
  authService
});
 
export function provideLbAppServices ():void {
  provide(LbAuthServiceKey, authService);
  provide(LbGraphqlServiceKey, gqlClient)
}

export interface CloudletServices {
  authService: LbAuthService;
  graphqlService: LbGraphqlService;
}

export const useCloudletServices = (): CloudletServices => {
  const authService = safeInject(LbAuthServiceKey);
  const graphqlService = safeInject(LbGraphqlServiceKey);

  return {
    authService,
    graphqlService
  };
};

